import * as React from 'react';
import { HTMLChakraProps, ThemingProps } from '@chakra-ui/system';
import { UseStepperProps } from './use-stepper';
export interface StepperProps extends UseStepperProps, Omit<HTMLChakraProps<'div'>, 'onChange'>, ThemingProps<'Stepper'> {
    orientation?: 'horizontal' | 'vertical';
}
/**
 * Display progress in multi-step workflows.
 *
 * Can be controlled or uncontrolled.
 */
export declare const Stepper: import("@chakra-ui/system/dist/system.types").ComponentWithAs<"div", StepperProps>;
export declare const StepperContainer: import("@chakra-ui/system/dist/system.types").ComponentWithAs<"div", StepperProps>;
export interface StepperStepsProps extends HTMLChakraProps<'div'> {
    orientation?: 'horizontal' | 'vertical';
    stepComponent?: React.JSXElementConstructor<any>;
}
/**
 * Wrapper element containing the steps.
 */
export declare const StepperSteps: React.FC<StepperStepsProps>;
export interface StepperContentProps extends HTMLChakraProps<'div'> {
    /**
     * Show or hide the content
     */
    isOpen?: boolean;
}
/**
 * Renders the step content, is collapsible.
 */
export declare const StepperContent: React.FC<StepperContentProps>;
export interface StepperIconProps extends HTMLChakraProps<'div'> {
    icon: React.ReactNode;
    isActive?: boolean;
    isCompleted?: boolean;
}
/**
 * Displays the current step or a completed icon.
 */
export declare const StepperIcon: React.FC<StepperIconProps>;
export interface StepperStepProps extends Omit<HTMLChakraProps<'div'>, 'title'> {
    /**
     * The step title
     */
    title: React.ReactNode;
    /**
     * The step name, used for controlled steppers
     */
    name?: string;
    /**
     * Show an icon instead of the step number
     */
    icon?: React.ReactNode;
    /**
     *
     */
    isActive?: boolean;
    /**
     *
     */
    isCompleted?: boolean;
}
/**
 * Displays the icon and step title.
 */
export declare const StepperStep: React.FC<StepperStepProps>;
export interface StepperSeparatorProps extends HTMLChakraProps<'div'> {
    isActive?: boolean;
}
/**
 * The separator between steps.
 */
export declare const StepperSeparator: React.FC<StepperSeparatorProps>;
/**
 * The step title.
 */
export declare const StepperStepTitle: React.FC<HTMLChakraProps<'p'>>;
/**
 * Shown when all steps have completed.
 */
export declare const StepperCompleted: React.FC<HTMLChakraProps<'div'>>;
//# sourceMappingURL=stepper.d.ts.map